logLik.msel: Extract Log-Likelihood from a Fit of the msel Function.

logLik.mselR Documentation

Extract Log-Likelihood from a Fit of the msel Function.

Description

Extract Log-Likelihood from a model fit of the msel function.

Usage

## S3 method for class 'msel'
logLik(object, ...)

Arguments

object

object of class "msel"

...

further arguments (currently ignored)

Details

If estimator == "2step" in msel then function may return NA value since the two-step estimator of the covariance matrix may not be positively defined.

Value

Returns an object of class 'logLik'.


switchSelection documentation built on April 15, 2026, 5:06 p.m.