update_msel: Update msel object with the new estimates

View source: R/bootstrap.R

update_mselR Documentation

Update msel object with the new estimates

Description

This function updates parameters of the model estimated via msel function.

Usage

update_msel(object, par)

Arguments

object

an object of class 'msel'.

par

a vector of parameters which substitutes object$par and is used to update the estimates i.e., object$coef, object$cuts and others.

Details

It may be useful to apply this function to the bootstrap estimates of bootstrap_msel.

Value

This function returns an object of class 'msel' in which object$par is substituted with par. Also, par is used to update the estimates i.e., object$coef, object$cuts and others.


switchSelection documentation built on April 15, 2026, 5:06 p.m.