| vcov.msel | R Documentation |
Return the variance-covariance matrix of the parameters of msel model.
## S3 method for class 'msel'
vcov(
object,
...,
type = object$cov_type,
n_cores = object$other$n_cores,
n_sim = object$other$n_sim,
recalculate = FALSE,
cluster = NULL
)
object |
an object of class |
... |
further arguments (currently ignored). |
type |
character representing the type of the asymptotic covariance
matrix estimator. It takes the same values as |
n_cores |
positive integer representing the number of CPU cores used for parallel computing. If possible it is highly recommended to set it equal to the number of available physical cores especially when the system of ordered equations has 2 or 3 equations. |
n_sim |
integer representing the number of GHK draws when there are more than 3 ordered equations. Otherwise alternative (much more efficient) algorithms will be used to calculate multivariate normal probabilities. |
recalculate |
logical; if |
cluster |
an object which takes the same values as the |
Argument type is closely related to the argument
cov_type of msel function.
See 'Details' and 'Usage' sections of msel
for more information on cov_type argument.
The user may also estimate asymptotic covariance matrix of the parameters
of several models. For more information, see paragraph 'Cross-model tests'
in 'Details' section of test_msel.
Returns numeric matrix which represents estimate of the asymptotic
covariance matrix of model's parameters. If object is a list of
models then rows and columns of this matrix will have names "mipj"
indicating that corresponding element is associated with j-th
parameter of the i-th model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.